# Streak-Cal

Streak-Cal is a cli calendar for keeping streaks going. Have something you want to do everyday? Keep a streak.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install streak-cal
```

## Usage

```bash
streak-cal --help
```
![streak-cal](https://github.com/kachaMukabe/streak/blob/main/assets/2020-11-16%2012-43-49.2020-11-16%2012_44_58.gif)

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)